import QtQuick 1.1
import com.nokia.meego 1.0
import QtMobility.location 1.2
import "main.js" as MainManager

Page {
    id: nearStationsPage

    orientationLock: PageOrientation.LockPortrait

    tools:
        ToolBarLayout {
        visible: true
        ToolIcon { iconId: "toolbar-back"; onClicked: { mainMenu.close(); pageStack.pop(); } }
        ToolIcon {
            Image {
                source: "images/info-icon.png"
                anchors.verticalCenter: parent.verticalCenter
                anchors.horizontalCenter: parent.horizontalCenter
            }
            onClicked: pageStack.push(Qt.resolvedUrl("StatusPage.qml"))
        }
        ToolIcon {
            iconId: "toolbar-search"
            onClicked: pageStack.push(Qt.resolvedUrl("SearchNearStations.qml"))
        }
        ToolIcon {
            iconId: "toolbar-view-menu"
            onClicked: (mainMenu.status == DialogStatus.Closed) ? mainMenu.open() : mainMenu.close()
            anchors.right: parent === undefined ? undefined : parent.right
        }
    }

    PositionSource {
        id: currentLocation
        updateInterval:3000
        active: true
        onPositionChanged: {
            indicator1.visible = false
            indicator1.running = false

            MainManager.update_location(currentLocation.position.coordinate.latitude,currentLocation.position.coordinate.longitude);
            window.getManager().generateClosestStationsModel(closestStationsModel);
            listView.visible = true
        }
    }

    ListModel {
        id: closestStationsModel
    }


    Component {
        id:stationsDelegate

        Item {
            height: listItem.height
            width: parent.width

            BorderImage {
                id: background
                anchors.fill: parent
                // Fill page borders
                anchors.leftMargin: -nearStationsPage.anchors.leftMargin
                anchors.rightMargin: -nearStationsPage.anchors.rightMargin
                visible: mouseArea.pressed
                source: "image://theme/meegotouch-list-fullwidth-background-pressed-center"
            }

            Item {
                id:listItem
                width:parent.width
                height: itemName.height + itemSubject.height + itemDistance.height + itemDistance.height

                Item {
                    id: itemIcon
                    width:96
                    height: parent.height
                    Image {
                        smooth: true
                        width: 64
                        height: 64
                        source: "images/" + letterline
                        anchors.verticalCenter: parent.verticalCenter
                        anchors.horizontalCenter: parent.horizontalCenter
                    }
                }

                Item {
                    id: itemLabels
                    width: listItem.width - 124
                    height: itemName.height + itemSubject.height + itemDistance.height
                    anchors.verticalCenter: parent.verticalCenter
                    anchors.left: itemIcon.right
                    anchors.leftMargin: 8

                    Label {
                        id:itemName
                        text: name
                        font.weight: Font.Bold
                        font.pixelSize: 26
                        lineHeightMode: Text.FixedHeight
                        lineHeight: font.pixelSize * 1.1
                    }
                    Label {
                        id:itemSubject
                        text: address
                        anchors.top: itemName.bottom
                        anchors.topMargin: 0
                        font.weight: Font.Normal
                        font.pixelSize: 22
                        lineHeightMode: Text.FixedHeight
                        lineHeight: font.pixelSize * 1.1
                    }
                    Label {
                        id:itemDistance
                        font.weight: Font.Normal
                        text: "Distancia: " + distance + " mts. aprox."
                        anchors.top: itemSubject.bottom
                        anchors.topMargin: 0
                        font.pixelSize: 18
                        lineHeightMode: Text.FixedHeight
                        lineHeight: font.pixelSize * 1.1
                    }
                }
            }


            Image {
                source: "image://theme/icon-m-common-drilldown-arrow" + (theme.inverted ? "-inverse" : "")
                anchors.right: parent.right
                anchors.rightMargin: 0
                anchors.verticalCenter: parent.verticalCenter
            }

            MouseArea {
                id: mouseArea
                anchors.fill: background
                onClicked: {
                    station_id = id
                    pageStack.push(Qt.resolvedUrl("StationDetailsPage.qml"))
                }
            }
        }
    }

    Rectangle {
        id:header
        width:parent.width
        height: 72
        z:10
        color:"#247800"
        Item {
            anchors.verticalCenter: parent.verticalCenter
            height: headerName.height + headerSubject.height
            Text {
                id:headerName
                text: "Estaciones Cercanas"
                color:"#fff"
                anchors.left: parent.left
                anchors.leftMargin: 16
                anchors.top: parent.top
                anchors.topMargin: 0
                font.pixelSize: 32
                font.weight: Font.Normal
                font.family: "Nokia Pure Text"
                lineHeightMode: Text.FixedHeight
                lineHeight: font.pixelSize * 1.1
            }
            Text {
                id:headerSubject
                text:"Seleccione una estación"
                color:"#fff"
                anchors.left: parent.left
                anchors.leftMargin: 16
                anchors.top: headerName.bottom
                anchors.topMargin: 0
                font.pixelSize: 18
                font.weight: Font.Normal
                font.family: "Nokia Pure Text"
                lineHeightMode: Text.FixedHeight
                lineHeight: font.pixelSize * 1.1
            }
        }
    }

    BusyIndicator {
        id: indicator1
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.verticalCenter: parent.verticalCenter
        running: true
        visible: true
        z:100
        platformStyle: BusyIndicatorStyle { size: "large" }
    }

    ListView {
        id:listView
        visible: false
        anchors.top: header.bottom
        anchors.topMargin: 8
        anchors.bottom: parent.bottom
        anchors.bottomMargin: 0
        anchors.left: parent.left
        anchors.right: parent.right
        model:closestStationsModel
        delegate:stationsDelegate
    }

    ScrollDecorator {
        flickableItem: listView
    }
}
