import QtQuick 1.1
import com.nokia.meego 1.0
import com.nokia.extras 1.1
import QtMobility.location 1.2
import "main.js" as MainManager

Page {
    id: searchNearStationsPage

    orientationLock: PageOrientation.LockPortrait

    tools: ToolBarLayout {
        ToolIcon { iconId: "toolbar-back"; onClicked: { mainMenu.close(); pageStack.pop(); } }
        ToolIcon {
            Image {
                source: "images/info-icon.png"
                anchors.verticalCenter: parent.verticalCenter
                anchors.horizontalCenter: parent.horizontalCenter
            }
            onClicked: pageStack.push(Qt.resolvedUrl("StatusPage.qml"))
        }
        ToolIcon {
            Image {
                source: "images/geo-icon.png"
                anchors.verticalCenter: parent.verticalCenter
                anchors.horizontalCenter: parent.horizontalCenter
            }
            onClicked: pageStack.push(Qt.resolvedUrl("NearStations.qml"))
        }
        ToolIcon {
            iconId: "toolbar-view-menu"
            onClicked: (mainMenu.status == DialogStatus.Closed) ? mainMenu.open() : mainMenu.close()
            anchors.right: parent===undefined ? undefined : parent.right
        }
    }

    property string locationType

    ListModel {
        id: closestStationsByDestinyModel
    }

    InfoBanner{
        id: errorBanner
        text: "Por favor verifique la dirección ingresada."
        timerEnabled: true
        timerShowTime: 4000
        topMargin: 8
        leftMargin: 8
        z:1000
    }

    Component {
        id:stationsDelegate

        Item {
            height: listItem.height
            width: parent.width

            BorderImage {
                id: background
                anchors.fill: parent
                // Fill page borders
                anchors.leftMargin: -searchNearStationsPage.anchors.leftMargin
                anchors.rightMargin: -searchNearStationsPage.anchors.rightMargin
                visible: mouseArea.pressed
                source: "image://theme/meegotouch-list-fullwidth-background-pressed-center"
            }

            Item {
                id:listItem
                width:parent.width
                height: itemName.height + itemSubject.height + itemDistance.height + itemDistance.height

                Item {
                    id: itemIcon
                    width:96
                    height: parent.height
                    Image {
                        smooth: true
                        width: 64
                        height: 64
                        source: "images/" + letterline
                        anchors.verticalCenter: parent.verticalCenter
                        anchors.horizontalCenter: parent.horizontalCenter
                    }
                }

                Item {
                    id: itemLabels
                    width: listItem.width - 124
                    height: itemName.height + itemSubject.height + itemDistance.height
                    anchors.verticalCenter: parent.verticalCenter
                    anchors.left: itemIcon.right
                    anchors.leftMargin: 8

                    Label {
                        id:itemName
                        text: name
                        font.weight: Font.Bold
                        font.pixelSize: 26
                        lineHeightMode: Text.FixedHeight
                        lineHeight: font.pixelSize * 1.1
                    }
                    Label {
                        id:itemSubject
                        text: address
                        anchors.top: itemName.bottom
                        anchors.topMargin: 0
                        font.weight: Font.Normal
                        font.pixelSize: 22
                        lineHeightMode: Text.FixedHeight
                        lineHeight: font.pixelSize * 1.1
                    }
                    Label {
                        id:itemDistance
                        font.weight: Font.Normal
                        text: "Distancia: " + distance + " mts. aprox."
                        anchors.top: itemSubject.bottom
                        anchors.topMargin: 0
                        font.pixelSize: 18
                        lineHeightMode: Text.FixedHeight
                        lineHeight: font.pixelSize * 1.1
                    }

                }


            }


            Image {
                source: "image://theme/icon-m-common-drilldown-arrow" + (theme.inverted ? "-inverse" : "")
                anchors.right: parent.right
                anchors.rightMargin: 0
                anchors.verticalCenter: parent.verticalCenter
            }

            MouseArea {
                id: mouseArea
                anchors.fill: background
                onClicked: {
                    station_id = id
                    pageStack.push(Qt.resolvedUrl("StationDetailsPage.qml"))
                }
            }
        }
    }

    Rectangle {
        id:header
        width:parent.width
        height: 72
        z:10
        color:"#247800"
        Item {
            anchors.verticalCenter: parent.verticalCenter
            height: headerName.height + headerSubject.height
            Text {
                id:headerName
                text: "Buscar Estaciones"
                color:"#fff"
                anchors.left: parent.left
                anchors.leftMargin: 16
                anchors.top: parent.top
                anchors.topMargin: 0
                font.pixelSize: 32
                font.weight: Font.Normal
                font.family: "Nokia Pure Text"
                lineHeightMode: Text.FixedHeight
                lineHeight: font.pixelSize * 1.1
            }
            Text {
                id:headerSubject
                text:"Encontra la estación mas cercana"
                color:"#fff"
                anchors.left: parent.left
                anchors.leftMargin: 16
                anchors.top: headerName.bottom
                anchors.topMargin: 0
                font.pixelSize: 18
                font.weight: Font.Normal
                font.family: "Nokia Pure Text"
                lineHeightMode: Text.FixedHeight
                lineHeight: font.pixelSize * 1.1
            }
        }
    }


    function getGeoData(){
        var xhr = new XMLHttpRequest;
        xhr.open("GET", "http://maps.googleapis.com/maps/api/geocode/json?address="+ destinationAddress.text +"Capital%20Federal%20Argentina&sensor=false", true);
        xhr.onreadystatechange = function() {
            if (xhr.readyState == 4) {
                var response = JSON.parse(xhr.responseText);

                if (response.results[0] === undefined){
                    errorBanner.show();
                    console.log("undefined")
                    console.log(resultLocation.latitude)
                }
                else {
                    indicator1.visible = true
                    indicator1.running = true
                    resultLocation.latitude = response.results[0].geometry.location.lat;
                    resultLocation.longitude = response.results[0].geometry.location.lng;
                    //locationType = response.results[0].type;
                    console.log(resultLocation.latitude)
                    delay.start();
                }
            }
        }
        xhr.send();
    }

    Timer {
        id:delay
        interval: 3000
        running: false
        repeat: false
        onTriggered: {
            MainManager.searchLocation(resultLocation.latitude, resultLocation.longitude);
            window.getManager().generateClosestStationsByDestinyModel(closestStationsByDestinyModel);
            indicator1.visible = false
            indicator1.running = false
        }
    }

    Rectangle {
        id:searchBox
        height: 80
        anchors.left: parent.left
        anchors.leftMargin: 0
        anchors.right: parent.right
        anchors.rightMargin: 0
        anchors.top: header.bottom
        anchors.topMargin: 0
        color:"#dedfde"
        z:10

        TextField {
            id: destinationAddress
            focus: false
            text: ""
            anchors.right: parent.right
            anchors.rightMargin: 16
            anchors.left: parent.left
            anchors.leftMargin: 16
            anchors.verticalCenter: parent.verticalCenter
            placeholderText: "Ingresar dirección"
            //validator: RegExpValidator{regExp: /[a-zA-Z0-9-_\.]/}

            //errorHighlight: text.length < 1
            platformSipAttributes: SipAttributes { actionKeyHighlighted: true }
            platformStyle: TextFieldStyle { paddingRight: clearButton.width }

            Image {
                id: clearButton
                anchors.right: parent.right
                anchors.verticalCenter: parent.verticalCenter
                source: "image://theme/icon-m-input-clear"
                MouseArea {
                    anchors.fill: parent
                    onClicked: {
                        inputContext.reset();
                        destinationAddress.text = "";
                    }
                }
            }

            Keys.onReturnPressed: {
                if (destinationAddress.text == ""){
                    destinationAddress.errorHighlight = true
                }
                else {
                    destinationAddress.errorHighlight = false
                    closestStationsByDestinyModel.clear()
                    getGeoData();
                    parent.focus = true;
                }
            }
        }
    }

    Image {
        id:separator
        anchors.top: searchBox.bottom
        anchors.topMargin: 0
        anchors.left: parent.left
        anchors.leftMargin: 16
        anchors.right: parent.right
        anchors.rightMargin: 16
        source: "images/separator.png"
        height: 2
    }


    ListView {
        id:listView
        anchors.top: separator.bottom
        anchors.topMargin: 16
        anchors.bottom: parent.bottom
        anchors.bottomMargin: 0
        anchors.left: parent.left
        anchors.right: parent.right
        model:closestStationsByDestinyModel
        delegate:stationsDelegate

        BusyIndicator {
            id: indicator1
            anchors.horizontalCenter: parent.horizontalCenter
            anchors.verticalCenter: parent.verticalCenter
            running: false
            visible: false
            z:100
            platformStyle: BusyIndicatorStyle { size: "large" }
        }
    }

    ScrollDecorator {
        flickableItem: listView
    }
}
