import QtQuick 1.1
import com.nokia.meego 1.0
import QtMobility.location 1.2

Page {
    id: stationsDetailsPage

    orientationLock: PageOrientation.LockPortrait
    Coordinate { id: defaultMapCenter; latitude: mapLat; longitude: mapLong}
    property int pinColor

    tools:
        ToolBarLayout {
        visible: true
        ToolIcon { iconId: "toolbar-back"; onClicked: { mainMenu.close(); pageStack.pop(); } }

        ToolButtonRow {
            id: buttonRow
            ToolButton {
                id:comb1
                width: 160
                visible: false
                onClicked: {
                    line_id = comb1_id
                    window.getManager().generateStationsModel(stationsModel, window.line_id);
                    pageStack.push(Qt.resolvedUrl("StationsPage.qml"))
                }
            }

            ToolButton {
                id:comb2
                width: 160
                visible: false
                onClicked: {
                    line_id = comb2_id
                    window.getManager().generateStationsModel(stationsModel, window.line_id);
                    pageStack.push(Qt.resolvedUrl("StationsPage.qml"))
                }
            }
        }
        ToolIcon {
            iconId: "toolbar-view-menu"
            onClicked: (mainMenu.status == DialogStatus.Closed) ? mainMenu.open() : mainMenu.close()
            anchors.right: parent === undefined ? undefined : parent.right
        }
    }


    BusyIndicator {
        id: indicator1
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.verticalCenter: parent.verticalCenter
        running: true
        z:100
        scale:1
    }

    Component.onCompleted: {
        indicator1.visible = false
        indicator1.running = false
    }

    ListModel {
        id:stationModel
        Component.onCompleted: {
            window.getManager().generateStationModel(stationModel, station_id);


            var pinColor
            pinColor = stationModel.get(0).pinColor

            pin.source = "images/pin_" + pinColor

            header.color = stationModel.get(0).color
            headerName.text = stationModel.get(0).name
            headerName.color = stationModel.get(0).foreground
            headerSubject.text = stationModel.get(0).address
            headerSubject.color = stationModel.get(0).foreground

            var lineCombination1_id
            var lineCombinationMessage1
            var lineCombination2_id
            var lineCombinationMessage2

            lineCombination1_id = stationModel.get(0).combination1_id
            lineCombinationMessage1 = stationModel.get(0).combinationMessage1
            lineCombination2_id = stationModel.get(0).combination2_id
            lineCombinationMessage2 = stationModel.get(0).combinationMessage2

            if (lineCombination2_id == "0"){
                comb2.visible = false
                buttonRow.visible = false
            }
            else {
                buttonRow.visible = true
                comb2.visible = true
                comb2.text = lineCombinationMessage2
                comb2_id = lineCombination2_id
                console.log("combinacion 2")
            }

            if (lineCombination1_id == "0"){
                comb1.visible = false
                buttonRow.visible = false
            }
            else {
                buttonRow.visible = true
                comb1.visible = true
                comb1.text = lineCombinationMessage1
                comb1_id = lineCombination1_id
                console.log("combinacion 1")
            }

            mapLat = stationModel.get(0).mapLat
            mapLong = stationModel.get(0).mapLong
        }
    }

    ListModel {
        id:stationsModel
    }

    Rectangle {
        id:header
        width:parent.width
        height: 72
        Item {
            anchors.verticalCenter: parent.verticalCenter
            height: headerName.height + headerSubject.height
            Text {
                id:headerName
                text:""
                anchors.left: parent.left
                anchors.leftMargin: 16
                anchors.top: parent.top
                anchors.topMargin: 0
                font.pixelSize: 32
                font.weight: Font.Normal
                font.family: "Nokia Pure Text"
                lineHeightMode: Text.FixedHeight
                lineHeight: font.pixelSize * 1.1
            }
            Text {
                id:headerSubject
                text:""
                anchors.left: parent.left
                anchors.leftMargin: 16
                anchors.top: headerName.bottom
                anchors.topMargin: 0
                font.pixelSize: 18
                font.weight: Font.Normal
                font.family: "Nokia Pure Text"
                lineHeightMode: Text.FixedHeight
                lineHeight: font.pixelSize * 1.1
            }
        }
    }


    Map {
        id: map
        mapType: mapOptions.selectedIndex >= 0 ? mapOptions.model.get(mapOptions.selectedIndex).value : "TransitMap"
        anchors.top: header.bottom
        anchors.topMargin: 0
        anchors.right: parent.right
        anchors.rightMargin: 0
        anchors.left: parent.left
        anchors.leftMargin: 0
        anchors.bottom: parent.bottom
        anchors.bottomMargin: 0
        plugin : Plugin {
            name : "nokia";
            parameters: [
                PluginParameter { name: "app_id"; value: "vCZKLhbqnhKrH29MJid0" },
                PluginParameter { name: "token"; value: "zpDSWFBWtWBGHJNmIMMxKQ%3D%3D" }
            ]
        }
        size.width: parent.width
        size.height: parent.height - header.height
        zoomLevel: 17
        center: defaultMapCenter

        MapImage {
            id : pin
            coordinate: defaultMapCenter
        }
    }

    PinchArea {
        id: pincharea
        z:9
        property double __oldZoom

        anchors.fill: parent

        function calcZoomDelta(zoom, percent) {
            return zoom + Math.log(percent)/Math.log(2)
        }

        onPinchStarted: {
            __oldZoom = map.zoomLevel
        }

        onPinchUpdated: {
            map.zoomLevel = calcZoomDelta(__oldZoom, pinch.scale)
        }

        onPinchFinished: {
            map.zoomLevel = calcZoomDelta(__oldZoom, pinch.scale)
        }
    }

    MouseArea {
        id: mousearea
        z:9
        property bool __isPanning: false
        property int __lastX: -1
        property int __lastY: -1

        anchors.fill : parent

        onPressed: {
            __isPanning = true
            __lastX = mouse.x
            __lastY = mouse.y
        }

        onReleased: {
            __isPanning = false
        }

        onPositionChanged: {
            if (__isPanning) {
                var dx = mouse.x - __lastX
                var dy = mouse.y - __lastY
                map.pan(-dx, -dy)
                __lastX = mouse.x
                __lastY = mouse.y
            }
        }

        onCanceled: {
            __isPanning = false;
        }
    }

    Image {
        id:mapSelector
        z:10
        source: "images/map_selector.png"
        width:48
        height:48
        anchors.right: parent.right
        anchors.rightMargin: 20
        anchors.top: header.bottom
        anchors.topMargin: 20
        Image {
            source:"images/toolbar-settings.png"
            width:30
            height: 30
            anchors.horizontalCenter: parent.horizontalCenter
            anchors.verticalCenter: parent.verticalCenter
        }

        MouseArea {
            id: mouseArea
            anchors.fill: parent
            onClicked: {
                mapOptions.open();
            }
        }
    }

    SelectionDialog {
        id: mapOptions
        titleText: "Opciones de mapa"

        model: ListModel {
            ListElement {
                name: "Mapa"
                value:"TransitMap"
            }
            ListElement {
                name: "Satélite"
                value:"HybridMap"
            }
            ListElement {
                name: "Terreno"
                value:"TerrainMap"
            }
        }

    }
}
