import QtQuick 1.1
import com.nokia.meego 1.0

Page {
    id: stationsPage

    orientationLock: PageOrientation.LockPortrait

    tools:
        ToolBarLayout {
        visible: true
        ToolIcon { iconId: "toolbar-back"; onClicked: { mainMenu.close(); pageStack.pop(); } }
        ToolIcon {
            Image {
                source: "images/info-icon.png"
                anchors.verticalCenter: parent.verticalCenter
                anchors.horizontalCenter: parent.horizontalCenter
            }
            onClicked: pageStack.push(Qt.resolvedUrl("StatusPage.qml"))
        }
        ToolIcon {
            Image {
                source: "images/geo-icon.png"
                anchors.verticalCenter: parent.verticalCenter
                anchors.horizontalCenter: parent.horizontalCenter
            }
            onClicked: pageStack.push(Qt.resolvedUrl("NearStations.qml"))
        }
        ToolIcon {
            iconId: "toolbar-search"
            onClicked: pageStack.push(Qt.resolvedUrl("SearchNearStations.qml"))
        }
        ToolIcon {
            iconId: "toolbar-view-menu"
            onClicked: (mainMenu.status == DialogStatus.Closed) ? mainMenu.open() : mainMenu.close()
            anchors.right: parent === undefined ? undefined : parent.right
        }
    }

    ListModel {
        id:lineModel
        Component.onCompleted: {
            window.getManager().generateLineModel(lineModel);
            header.color = lineModel.get(0).headerColor
            headerName.text = lineModel.get(0).lineName
            headerName.color = lineModel.get(0).lineForeground
            headerSubject.text = lineModel.get(0).lineSubject
            headerSubject.color = lineModel.get(0).lineForeground
            infoBarTimeTravel.text = "Duración del recorrido: " + lineModel.get(0).timeTravel

            var currentFrecuency
            var lineFrecuency
            var lineFrecuencySat
            var lineFrecuencySun


            lineFrecuency = lineModel.get(0).frecuency
            lineFrecuencySat = lineModel.get(0).frecuencySat
            lineFrecuencySun = lineModel.get(0).frecuencySun

            var t = new Date();
            var f = Qt.formatDate(t, "dddd");


            if (f == "Saturday"){
                currentFrecuency = lineFrecuencySat
            }
            else if (f == "Sunday") {
                currentFrecuency = lineFrecuencySun
            }
            else {
                currentFrecuency = lineFrecuency
            }

            infoBarCurrentFrecuency.text = " | Trenes cada: " + currentFrecuency + "aprox."
        }
    }

    ListModel {
        id:stationsModel
        Component.onCompleted: {
            window.getManager().generateStationsModel(stationsModel, window.line_id);
            console.log(line_id);
            //setFrecuency()
        }
    }

    Component {
        id:stationsDelegate
        Item {
            height: 82
            width: parent.width

            BorderImage {
                id: background
                anchors.fill: parent
                // Fill page borders
                anchors.leftMargin: -stationsPage.anchors.leftMargin
                anchors.rightMargin: -stationsPage.anchors.rightMargin
                visible: mouseArea.pressed
                source: "image://theme/meegotouch-list-fullwidth-background-pressed-center"
            }

            Row {
                anchors.fill: parent
                Column {
                    anchors.verticalCenter: parent.verticalCenter
                    Image {
                        id:gfx
                        smooth: true
                        width: 80
                        height: 80
                        source: "images/" + icon
                    }
                }

                Column {
                    anchors.verticalCenter: parent.verticalCenter
                    Label {
                        id:itemName
                        text: name
                        font.weight: Font.Bold
                        font.pixelSize: 26
                        lineHeightMode: Text.FixedHeight
                        lineHeight: font.pixelSize * 1.1
                    }
                    Label {
                        id:itemSubject
                        text: address
                        font.weight: Font.Normal
                        font.pixelSize: 22
                        lineHeightMode: Text.FixedHeight
                        lineHeight: font.pixelSize * 1.1
                    }
                }

            }
            Image {
                source: "image://theme/icon-m-common-drilldown-arrow" + (theme.inverted ? "-inverse" : "")
                anchors.right: parent.right;
                anchors.verticalCenter: parent.verticalCenter
            }

            MouseArea {
                id: mouseArea
                anchors.fill: background
                onClicked: {
                    station_id = id
                    pageStack.push(Qt.resolvedUrl("StationDetailsPage.qml"))
                }
            }
        }
    }

    Rectangle {
        id:header
        width:parent.width
        height: 72
        z:10
        Item {
            anchors.verticalCenter: parent.verticalCenter
            height: headerName.height + headerSubject.height
            Text {
                id:headerName
                text:""
                anchors.left: parent.left
                anchors.leftMargin: 16
                anchors.top: parent.top
                anchors.topMargin: 0
                font.pixelSize: 32
                font.weight: Font.Normal
                font.family: "Nokia Pure Text"
                lineHeightMode: Text.FixedHeight
                lineHeight: font.pixelSize * 1.1
            }
            Text {
                id:headerSubject
                text:""
                anchors.left: parent.left
                anchors.leftMargin: 16
                anchors.top: headerName.bottom
                anchors.topMargin: 0
                font.pixelSize: 18
                font.weight: Font.Normal
                font.family: "Nokia Pure Text"
                lineHeightMode: Text.FixedHeight
                lineHeight: font.pixelSize * 1.1
            }
        }
    }

    Rectangle {
        id:subHeader
        width:parent.width
        height: 26
        z:10
        color:"#333"
        anchors.top: header.bottom
        anchors.topMargin: 0

        Text {
            id:infoBarTimeTravel
            text: ""
            color:"#fff"
            font.weight: Font.Normal
            font.family: "Nokia Pure Text"
            font.pixelSize:16
            anchors.left: parent.left
            anchors.verticalCenter: parent.verticalCenter
            anchors.leftMargin: 16

        }

        Text {
            id:infoBarCurrentFrecuency
            text:""
            color:"#fff"
            font.weight: Font.Normal
            font.family: "Nokia Pure Text"
            font.pixelSize:16
            anchors.left: infoBarTimeTravel.right
            anchors.verticalCenter: parent.verticalCenter
            anchors.leftMargin: 0

        }
    }

    ListView {
        id:listView
        anchors.top: subHeader.bottom
        anchors.topMargin: 8
        anchors.bottom: parent.bottom
        anchors.bottomMargin: 8
        anchors.left: parent.left
        anchors.right: parent.right
        model:stationsModel
        delegate:stationsDelegate
    }

    ScrollDecorator {
        flickableItem: listView
    }
}
