import QtQuick 1.1
import com.nokia.meego 1.0
import com.nokia.extras 1.1

Page {
    id: statusPage

    orientationLock: PageOrientation.LockPortrait

    tools:
        ToolBarLayout {
        visible: true
        ToolIcon { iconId: "toolbar-back"; onClicked: { mainMenu.close(); pageStack.pop(); } }
        ToolIcon {
            Image {
                source: "images/geo-icon.png"
                anchors.verticalCenter: parent.verticalCenter
                anchors.horizontalCenter: parent.horizontalCenter
            }
            onClicked: pageStack.push(Qt.resolvedUrl("NearStations.qml"))
        }
        ToolIcon {
            iconId: "toolbar-search"
            onClicked: pageStack.push(Qt.resolvedUrl("SearchNearStations.qml"))
        }
        ToolIcon {
            iconId: "toolbar-view-menu"
            onClicked: (mainMenu.status === DialogStatus.Closed) ? mainMenu.open() : mainMenu.close()
            anchors.right: parent === undefined ? undefined : parent.right
        }
    }


    XmlListModel {
        id:statusModel
        source: "http://realnorth.net/subtego/feed/twitter_json_to_rss.php?screen_name=subteba"
        query: "/rss/channel/item"

        XmlRole { name: "description"; query: "description/string()" }

        onCountChanged: {
            indicator1.running = false
            indicator1.visible = false
        }
    }

    Component {
        id:statusDelegate
        Item {
            id:listItem
            height: itemSubject.height + 16
            width: parent.width

            Image {
                id:itemIcon
                smooth: true
                width: 64
                height: 64
                anchors.left: parent.left
                anchors.leftMargin: 16
                anchors.verticalCenter: parent.verticalCenter
                source: ""
            }

            Label {
                id:itemSubject
                text: description
                wrapMode: Text.WordWrap
                font.weight: Font.Normal
                font.pixelSize: 22
                lineHeightMode: Text.FixedHeight
                lineHeight: font.pixelSize * 1.1
                anchors.topMargin: 0
                anchors.verticalCenter: parent.verticalCenter
                anchors.left: itemIcon.right
                anchors.leftMargin: 16
                width: listItem.width - 112
            }

            Component.onCompleted: {
                var text = itemSubject.text
                if (text.indexOf("Interrumpido") > -1) {
                    itemSubject.color = "#ff0000"
                }
                else if (text.indexOf("Interrupción") > -1){
                    itemSubject.color = "#ff0000"
                }
                else if (text.indexOf("INTERRUPCION") > -1){
                    itemSubject.color = "#ff0000"
                }
                else if (text.indexOf("demora") > -1){
                    itemSubject.color = "#ff0000"
                }
                else if (text.indexOf("limitado") > -1){
                    itemSubject.color = "#ff5555"
                }
                else if (text.indexOf("Normalizado") > -1){
                    itemSubject.color = "#008000"
                }
                else {
                    itemSubject.color = "#333333"
                }

                if (text.indexOf("Línea A") > -1) {
                    itemIcon.source = "images/a.png"
                }
                else if (text.indexOf("Línea B") > -1){
                    itemIcon.source = "images/b.png"
                }
                else if (text.indexOf("Línea C") > -1){
                    itemIcon.source = "images/c.png"
                }
                else if (text.indexOf("Línea D") > -1){
                    itemIcon.source = "images/d.png"
                }
                else if (text.indexOf("Línea E") > -1){
                    itemIcon.source = "images/e.png"
                }
                else if (text.indexOf("Línea H") > -1){
                    itemIcon.source = "images/h.png"
                }
                else if (text.indexOf("Línea P") > -1){
                    itemIcon.source = "images/p.png"
                }
                else {
                    itemIcon.source = "images/info.png"
                }
            }
        }
    }

    Rectangle {
        id:header
        width:parent.width
        height: 72
        z:10
        color:"#247800"
        Item {
            id: item1
            anchors.verticalCenter: parent.verticalCenter
            height: headerName.height + headerSubject.height
            Text {
                id:headerName
                color:"#fff"
                text:"Estado del Servicio"
                anchors.left: parent.left
                anchors.leftMargin: 16
                anchors.top: parent.top
                anchors.topMargin: 0
                font.pixelSize: 32
                font.weight: Font.Normal
                font.family: "Nokia Pure Text"
                lineHeightMode: Text.FixedHeight
                lineHeight: font.pixelSize * 1.1
            }
            Text {
                id:headerSubject
                color:"#fff"
                text:"Información cortesía de @subteba"
                anchors.left: parent.left
                anchors.leftMargin: 16
                anchors.top: headerName.bottom
                anchors.topMargin: 0
                font.pixelSize: 18
                font.weight: Font.Normal
                font.family: "Nokia Pure Text"
                lineHeightMode: Text.FixedHeight
                lineHeight: font.pixelSize * 1.1
            }
        }
    }

    BusyIndicator {
        id: indicator1
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.verticalCenter: parent.verticalCenter
        running: true
        z:100
        platformStyle: BusyIndicatorStyle { size: "large" }
        visible: true
    }

    ListView {
        id:listView
        anchors.top: header.bottom
        anchors.topMargin: 8
        anchors.right: parent.right
        anchors.bottom: parent.bottom
        anchors.left: parent.left
        model:statusModel
        delegate:statusDelegate
    }

    ScrollDecorator {
        flickableItem: listView
    }
}
